@@ -1,5 +1,5 @@
 
-#' @title Quick ApexChart
+#' @title Quick ApexCharts
 #' 
 #' @description Initialize a chart with three main parameters :
 #'  data, mapping and type of chart.
@@ -12,7 +12,8 @@
 #'  \code{"line"}, \code{"step"}, \code{"spline"},
 #'  \code{"area"}, \code{"area-step"}, \code{"area-spline"}, 
 #'  \code{"pie"}, \code{"donut"},
-#'  \code{"radialBar"}, \code{"radar"}, \code{"scatter"}, \code{"heatmap"}, 
+#'  \code{"radialBar"}, \code{"radar"}, \code{"scatter"},
+#'  \code{"heatmap"}, \code{"treemap"}, 
 #'  \code{"timeline"}.
 #' @param ... Other arguments passed on to methods. Not currently used.
 #' @param auto_update In Shiny application, update existing chart
@@ -50,8 +51,10 @@ apex <- function(data, mapping, type = "column", ...,
       "pie", "donut", 
       "radialBar",
       "radar", 
+      "polarArea",
       "scatter", "bubble", 
       "heatmap",
+      "treemap",
       "timeline",
       "candlestick"
     )
@@ -64,7 +67,7 @@ apex <- function(data, mapping, type = "column", ...,
     type <- "bubble"
   }
   mapdata <- lapply(mapping, rlang::eval_tidy, data = data)
-  if (type %in% c("pie", "donut", "radialBar")) {
+  if (type %in% c("pie", "donut", "radialBar", "polarArea")) {
     opts <- list(
       chart = list(type = correct_type(type)),
       series = list1(mapdata$y),
